@@ -10,7 +10,7 @@ with 'BorderStyleRole::Transform::BoxChar';
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-02-14'; # DATE
 our $DIST = 'BorderStyles-Standard'; # DIST
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 our $PICTURE = <<'_';
 qqqqqqqqqqqqqqqqq'
@@ -45,7 +45,49 @@ BorderStyle::BoxChar::SingleLineHorizontalOnly - Single line border with box-dra
 
 =head1 VERSION
 
-This document describes version 0.012 of BorderStyle::BoxChar::SingleLineHorizontalOnly (from Perl distribution BorderStyles-Standard), released on 2022-02-14.
+This document describes version 0.013 of BorderStyle::BoxChar::SingleLineHorizontalOnly (from Perl distribution BorderStyles-Standard), released on 2022-02-14.
+
+=head1 SYNOPSIS
+
+To use with L<Text::ANSITable>:
+
+ use Text::ANSITable;
+ my $rows =
+   [
+     ["ColumName1", "ColumnNameB", "ColumnNameC"],
+     ["row1A", "row1B", "row1C"],
+     ["row2A", "row2B", "row2C"],
+     ["row3A", "row3B", "row3C"],
+   ];
+ my $t = Text::ANSITable->new;
+ $t->border_style("BoxChar::SingleLineHorizontalOnly");
+ $t->columns($rows->[0]);
+ $t->add_row($rows->[$_]) for 1 .. $#{ $rows };
+ print $t->draw;
+
+To use with L<Text::Table::More>:
+
+ use Text::Table::More qw/generate_table/;
+ my $rows =
+   [
+     ["ColumName1", "ColumnNameB", "ColumnNameC"],
+     ["row1A", "row1B", "row1C"],
+     ["row2A", "row2B", "row2C"],
+     ["row3A", "row3B", "row3C"],
+   ];
+ generate_table(rows=>$rows, header_row=>1, separate_rows=>1, border_style=>"BoxChar::SingleLineHorizontalOnly");
+
+To use with L<Text::Table::TinyBorderStyle>:
+
+ use Text::Table::TinyBorderStyle qw/generate_table/;
+ my $rows =
+   [
+     ["ColumName1", "ColumnNameB", "ColumnNameC"],
+     ["row1A", "row1B", "row1C"],
+     ["row2A", "row2B", "row2C"],
+     ["row3A", "row3B", "row3C"],
+   ];
+ generate_table(rows=>$rows, header_row=>1, separate_rows=>1, border_style=>"BorderStyle::BoxChar::SingleLineHorizontalOnly");
 
 =head1 HOMEPAGE
 
